@@ -1,5 +1,7 @@
+from functools import partial
 from typing import TYPE_CHECKING, List, MutableSequence, Optional, Tuple
 
+from dvc_objects.executors import ThreadPoolExecutor
 from dvc_objects.fs.callbacks import DEFAULT_CALLBACK
 from dvc_objects.fs.generic import transfer
 
@@ -10,8 +12,7 @@ if TYPE_CHECKING:
     from dvc_objects.fs.base import FileSystem
     from dvc_objects.fs.callbacks import Callback
 
-    from .diff import Change
-    from .index import BaseDataIndex
+    from .index import BaseDataIndex, DataIndexEntry
 
 
 def checkout(
@@ -23,6 +24,7 @@ def checkout(
     callback: "Callback" = DEFAULT_CALLBACK,
     latest_only: bool = True,
     update_meta: bool = True,
+    jobs: Optional[int] = None,
     **kwargs,
 ) -> int:
     transferred = 0
@@ -39,40 +41,60 @@ def checkout(
                 for _, entry in index.iteritems()
             )
         )
-    for entry in create:
-        if entry.meta and entry.meta.isdir:
-            continue
-
-        entry_path = fs.path.join(path, *entry.key)
-        if (
-            not latest_only
-            and fs.version_aware
-            and entry.meta.version_id is not None
-            and fs.exists(
-                fs.path.version_path(entry_path, entry.meta.version_id)
-            )
-        ):
-            continue
-
-        sources = []
-        if entry.hash_info:
-            odb = entry.odb or entry.cache or entry.remote
-            sources.append((odb.fs, odb.oid_to_path(entry.hash_info.value)))
-        if entry.fs and entry.path:
-            sources.append((entry.fs, entry.path))
-        fs.makedirs(fs.path.parent(entry_path), exist_ok=True)
-        _try_sources(fs, entry_path, sources, callback=callback)
-        if update_meta:
-            entry.fs = fs
-            entry.path = entry_path
-            entry.meta = Meta.from_info(fs.info(entry_path), fs.protocol)
-        transferred += 1
+    processor = partial(
+        _do_create,
+        path,
+        fs,
+        callback=callback,
+        latest_only=latest_only,
+        update_meta=update_meta,
+    )
+    with ThreadPoolExecutor(max_workers=jobs or fs.jobs) as executor:
+        transferred += sum(executor.imap_unordered(processor, create))
     return transferred
 
 
+def _do_create(
+    path: str,
+    fs: "FileSystem",
+    entry: "DataIndexEntry",
+    callback: "Callback" = DEFAULT_CALLBACK,
+    latest_only: bool = True,
+    update_meta: bool = True,
+) -> int:
+    assert entry.meta
+    if entry.meta.isdir:
+        return 0
+
+    entry_path = fs.path.join(path, *entry.key)
+    if (
+        not latest_only
+        and fs.version_aware
+        and entry.meta.version_id is not None
+        and fs.exists(fs.path.version_path(entry_path, entry.meta.version_id))
+    ):
+        callback.relative_update()
+        return 0
+
+    sources = []
+    if entry.hash_info:
+        odb = entry.odb or entry.cache or entry.remote
+        assert odb
+        sources.append((odb.fs, odb.oid_to_path(entry.hash_info.value)))
+    if entry.fs and entry.path:
+        sources.append((entry.fs, entry.path))
+    fs.makedirs(fs.path.parent(entry_path), exist_ok=True)
+    _try_sources(fs, entry_path, sources, callback=callback)
+    if update_meta:
+        entry.fs = fs
+        entry.path = entry_path
+        entry.meta = Meta.from_info(fs.info(entry_path), fs.protocol)
+    return 1
+
+
 def _get_changes(
     index: "BaseDataIndex", old: Optional["BaseDataIndex"], **kwargs
-) -> Tuple[List["Change"], List["Change"]]:
+) -> Tuple[List["DataIndexEntry"], List["DataIndexEntry"]]:
     create = []
     delete = []
     for change in diff(old, index, **kwargs):
