@@ -1,6 +1,6 @@
 import os
 
-from dvc_objects.fs import LocalFileSystem
+from dvc_objects.fs import localfs
 from dvc_objects.fs.base import FileSystem
 
 from .index import DataIndex
@@ -10,9 +10,6 @@ class NotARepo(Exception):
     pass
 
 
-localfs = LocalFileSystem()
-
-
 class Repo:
     def __init__(self, root: str = "", fs: FileSystem = None) -> None:
         fs = fs or localfs
